@@ -21,7 +21,7 @@ except NameError:
 	_ = lambda x: x
 
 
-_moduleLogger = logging.getLogger("history")
+_moduleLogger = logging.getLogger(__name__)
 
 
 class HistorySelectionDialog(gtk.Dialog):
